@@ -4,6 +4,7 @@
 import os
 import json
 import fileinput
+import warnings
 import pickle
 import pandas as pd
 import inspect
@@ -75,21 +76,34 @@ def dump_lines(data: List[Any], file: str) -> NoReturn:
             print(d, file=fout)
 
 
-def load_line(file: str, separator: Union[None, str] = None, separator_time: int = -1) -> List[Any]:
+def load_line(
+        file: str,
+        separator: Union[None, str] = None,
+        separator_time: int = -1,
+        form: str = None,
+) -> List[Any]:
     with open(file, 'r', encoding='utf8') as fin:
         for line in fin:
-            item = line.strip()
+            item = line.rstrip('\n\r')
             if separator:
                 if separator_time == -1:
                     item = item.split(separator)
                 else:
                     item = item.split(separator, separator_time)
+            if form == 'set':
+                item = set(item)
             yield item
 
 
-def load_big_data(file: str, separator: Union[None, str] = None, separator_time: int = -1) -> List[Any]:
+def load_big_data(
+        file: str,
+        separator: Union[None, str] = None,
+        separator_time: int = -1,
+        form: str = None,
+) -> List[Any]:
+    warnings.warn("load_big_data 和 load_line 的功能一样，但内部实现不同，推荐优先使用load_line ", DeprecationWarning)
     for line in fileinput.input([file]):
-        item = line.strip()
+        item = line.rstrip('\n\r')
         if separator:
             if separator_time == -1:
                 item = item.split(separator)
@@ -98,20 +112,35 @@ def load_big_data(file: str, separator: Union[None, str] = None, separator_time:
         yield item
 
 
-def load_lines(file: str, separator: Union[None, str] = None, separator_time: int = -1) -> List[Any]:
+def load_lines(
+        file: str,
+        separator: Union[None, str] = None,
+        separator_time: int = -1,
+        form: str = None,
+) -> List[Any]:
     data = []
     with open(file, 'r', encoding='utf8') as fin:
         for d in fin.readlines():
-            item = d.strip()
+            item = d.rstrip('\n\r')
             if separator:
                 if separator_time == -1:
                     item = item.split(separator)
                 else:
                     item = item.split(separator, separator_time)
             data.append(item)
+    if form == 'set':
+        data = set(data)
+    if form == 'dict':
+        print('dict格式用每行的第一个元素作为key, 其后的元素的列表作为value。'
+              '如果一行中不包含多个元素会报错。'
+              '如果有相同的第一个元素会发生覆盖。')
+        data = {item[0]: item[1:] for item in data}
     return data
 
 
+MAX_LENGTH_XLSX = 1048576
+
+
 def dump_panda(
         data: List[Any],
         file: str,
@@ -123,13 +152,30 @@ def dump_panda(
     if 'index' in kwargs and isinstance(kwargs['index'], bool):
         raise ValueError('The parameter `index` is for pd.DataFrame. '
                          'If want to set the `index` for panda.to_csv/excel please use `dump_index`')
-    selected_kwargs, _ = split_dict(kwargs, inspect.getfullargspec(pd.DataFrame).args)
-    df = pd.DataFrame(data, **selected_kwargs)
-    selected_kwargs, _ = split_dict(kwargs, inspect.getfullargspec(df.to_csv).args)
-    selected_kwargs['index'] = dump_index
     if file_format == 'excel':
-        df.to_excel(file, **selected_kwargs)
+        if len(data) < MAX_LENGTH_XLSX - 100:
+            selected_kwargs, _ = split_dict(kwargs, inspect.getfullargspec(pd.DataFrame).args)
+            df = pd.DataFrame(data, **selected_kwargs)
+            selected_kwargs, _ = split_dict(kwargs, inspect.getfullargspec(df.to_csv).args)
+            selected_kwargs['index'] = dump_index
+            df.to_excel(file, **selected_kwargs)
+        else:
+            piece_num = 0
+            while data:
+                piece_data = data[:MAX_LENGTH_XLSX - 100]
+                piece_file = file + '_piece_' + str(piece_num) + '.xlsx'
+                data = data[MAX_LENGTH_XLSX - 100:]
+                selected_kwargs, _ = split_dict(kwargs, inspect.getfullargspec(pd.DataFrame).args)
+                df = pd.DataFrame(piece_data, **selected_kwargs)
+                selected_kwargs, _ = split_dict(kwargs, inspect.getfullargspec(df.to_csv).args)
+                selected_kwargs['index'] = dump_index
+                df.to_excel(piece_file, **selected_kwargs)
+                piece_num += 1
     if file_format == 'csv':
+        selected_kwargs, _ = split_dict(kwargs, inspect.getfullargspec(pd.DataFrame).args)
+        df = pd.DataFrame(data, **selected_kwargs)
+        selected_kwargs, _ = split_dict(kwargs, inspect.getfullargspec(df.to_csv).args)
+        selected_kwargs['index'] = dump_index
         df.to_csv(file, **selected_kwargs)
 
 
@@ -219,4 +265,6 @@ def prepare_data(url: str, directory: str = '', packed: bool = False, pack_way:
 
 
 if __name__ == '__main__':
-    pass
+    test_data = [[i] for i in range(26)]
+    test_file = 'test.xlsx'
+    dump_excel(test_data, test_file)
